@@ -147,7 +147,15 @@ class _Project(_Base):
         else:
             url = f'/projects/{self.key}/models/{datasource_key}'
         with open(path, 'rb') as f:
-            self._make_request('POST', url, files={'modelfile': f})
+            file_name = os.path.basename(path)
+            params = {
+                'filename':  file_name,
+                'datasourceKey': datasource_key
+            }
+            upload_url = self._make_request('GET', f'/projects/{self.key}/models/presigned-url', params=params)['uploadUrl']
+            requests.put(upload_url, data=f.read())
+
+            self._make_request('POST', url)
 
     def pull_model(self, filepath, datasource_key=None, round=None, federated_model=None, throw_error=False):
         params = {}
@@ -314,6 +322,9 @@ class DynamoFL(_Base):
                 hyper_param_values = p['hyper_param_values']
                 break
 
+        if trainer_key not in self.datasources[datasource_key].trainers:
+            return
+
         train = self.datasources[datasource_key].trainers[trainer_key]['train']
         test = self.datasources[datasource_key].trainers[trainer_key]['test']
         model_path = 'models'
